@@ -33,10 +33,6 @@ class Command(NoArgsCommand):
 
         if sync_public and schema_name:
             raise CommandError("schema should only be used with the --tenant switch.")
-        if not hasattr(settings, 'TENANT_APPS') and sync_tenant:
-            raise CommandError("No setting found for TENANT_APPS")
-        if not hasattr(settings, 'SHARED_APPS') and sync_public:
-            raise CommandError("No setting found for SHARED_APPS")
 
         # save original settings
         for model in get_models(include_auto_created=True):
@@ -105,4 +101,4 @@ class Command(NoArgsCommand):
         apps = self.shared_apps or self.installed_apps
         self._set_managed_apps(apps)
         print self.style.NOTICE("=== Running syncdb for schema public")
-        SyncdbCommand().execute(**self.options)
\ No newline at end of file
+        SyncdbCommand().execute(**self.options)
